@@ -36,8 +36,16 @@ struct _GnomeDbGridPrivate {
 	GtkWidget *tree_view;
 };
 
-static void gnome_db_grid_class_init (GnomeDbGridClass *klass);
-static void gnome_db_grid_init       (GnomeDbGrid *grid, GnomeDbGridClass *klass);
+static void gnome_db_grid_class_init   (GnomeDbGridClass *klass);
+static void gnome_db_grid_init         (GnomeDbGrid *grid, GnomeDbGridClass *klass);
+static void gnome_db_grid_set_property (GObject *object,
+					guint paramid,
+					const GValue *value,
+					GParamSpec *pspec);
+static void gnome_db_grid_get_property (GObject *object,
+					guint param_id,
+					GValue *value,
+					GParamSpec *pspec);
 static void gnome_db_grid_finalize   (GObject *object);
 
 enum {
@@ -46,6 +54,11 @@ enum {
 	LAST_SIGNAL
 };
 
+enum {
+	PROP_0,
+	PROP_MODEL
+};
+
 static gint gnome_db_grid_signals[LAST_SIGNAL] = { 0 };
 static GdkAtom clipboard_atom = GDK_NONE;
 static GObjectClass *parent_class = NULL;
@@ -101,6 +114,20 @@ gnome_db_grid_class_init (GnomeDbGridClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	object_class->set_property = gnome_db_grid_set_property;
+	object_class->get_property = gnome_db_grid_get_property;
+	object_class->finalize = gnome_db_grid_finalize;
+	klass->row_selected = NULL;
+	klass->row_unselected = NULL;
+
+	/* add class properties */
+	g_object_class_install_property (
+		object_class, PROP_MODEL,
+		g_param_spec_object ("model", NULL, NULL,
+				     GDA_TYPE_DATA_MODEL,
+				     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+
+	/* add class signals */
 	gnome_db_grid_signals[ROW_SELECTED] =
 		g_signal_new ("row_selected",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -118,10 +145,6 @@ gnome_db_grid_class_init (GnomeDbGridClass *klass)
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 
-	object_class->finalize = gnome_db_grid_finalize;
-	klass->row_selected = NULL;
-	klass->row_unselected = NULL;
-
 	/* clipboard atom */
 	if (!clipboard_atom)
 		clipboard_atom = gdk_atom_intern ("CLIPBOARD", FALSE);
@@ -142,6 +165,46 @@ gnome_db_grid_init (GnomeDbGrid *grid, GnomeDbGridClass *klass)
 	setup_grid (grid);
 }
 
+static void
+gnome_db_grid_set_property (GObject *object,
+			    guint param_id,
+			    const GValue *value,
+			    GParamSpec *pspec)
+{
+	GnomeDbGrid *grid = (GnomeDbGrid *) object;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	switch (param_id) {
+	case PROP_MODEL :
+		gnome_db_grid_set_model (grid, GDA_DATA_MODEL (g_value_get_object (value)));
+		break;
+	default :
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
+static void
+gnome_db_grid_get_property (GObject *object,
+			    guint param_id,
+			    GValue *value,
+			    GParamSpec *pspec)
+{
+	GnomeDbGrid *grid = (GnomeDbGrid *) object;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	switch (param_id) {
+	case PROP_MODEL :
+		g_value_set_object (value, G_OBJECT (grid->priv->model));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
 static void
 gnome_db_grid_finalize (GObject *object)
 {
