@@ -32,9 +32,17 @@ struct _GnomeDbListPrivate {
 	GtkWidget *grid;
 };
 
-static void gnome_db_list_class_init (GnomeDbListClass *klass);
-static void gnome_db_list_init       (GnomeDbList *list, GnomeDbListClass *klass);
-static void gnome_db_list_finalize   (GObject *object);
+static void gnome_db_list_class_init   (GnomeDbListClass *klass);
+static void gnome_db_list_init         (GnomeDbList *list, GnomeDbListClass *klass);
+static void gnome_db_list_set_property (GObject *object,
+					guint paramid,
+					const GValue *value,
+					GParamSpec *pspec);
+static void gnome_db_list_get_property (GObject *object,
+					guint param_id,
+					GValue *value,
+					GParamSpec *pspec);
+static void gnome_db_list_finalize     (GObject *object);
 
 enum {
 	ROW_SELECTED,
@@ -42,6 +50,11 @@ enum {
 	LAST_SIGNAL
 };
 
+enum {
+	PROP_0,
+	PROP_MODEL
+};
+
 static gint list_signals[LAST_SIGNAL];
 static GObjectClass *parent_class = NULL;
 
@@ -74,6 +87,18 @@ gnome_db_list_class_init (GnomeDbListClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	object_class->set_property = gnome_db_list_set_property;
+	object_class->get_property = gnome_db_list_get_property;
+	object_class->finalize = gnome_db_list_finalize;
+
+	/* add class properties */
+	g_object_class_install_property (
+		object_class, PROP_MODEL,
+		g_param_spec_object ("model", NULL, NULL,
+				     GDA_TYPE_DATA_MODEL,
+				     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+
+	/* add class signals */
 	list_signals[ROW_SELECTED] =
 		g_signal_new ("row_selected",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -90,8 +115,6 @@ gnome_db_list_class_init (GnomeDbListClass *klass)
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
-
-	object_class->finalize = gnome_db_list_finalize;
 }
 
 static void
@@ -113,6 +136,48 @@ gnome_db_list_init (GnomeDbList *list, GnomeDbListClass *klass)
 	gtk_box_pack_start (GTK_BOX (list), list->priv->grid, TRUE, TRUE, 0);
 }
 
+static void
+gnome_db_list_set_property (GObject *object,
+			    guint param_id,
+			    const GValue *value,
+			    GParamSpec *pspec)
+{
+	GnomeDbList *list = (GnomeDbList *) object;
+
+	g_return_if_fail (GNOME_DB_IS_LIST (list));
+
+	switch (param_id) {
+	case PROP_MODEL :
+		gnome_db_list_set_model (list,
+					 GDA_DATA_MODEL (g_value_get_object (value)),
+					 0);
+		break;
+	default :
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
+static void
+gnome_db_list_get_property (GObject *object,
+			    guint param_id,
+			    GValue *value,
+			    GParamSpec *pspec)
+{
+	GnomeDbList *list = (GnomeDbList *) object;
+
+	g_return_if_fail (GNOME_DB_IS_LIST (list));
+
+	switch (param_id) {
+	case PROP_MODEL :
+		g_value_set_object (value, G_OBJECT (list->priv->data_model));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
 static void
 gnome_db_list_finalize (GObject *object)
 {
