@@ -39,9 +39,24 @@ struct _GnomeDbLoginPrivate {
 	GtkWidget *password_entry;
 };
 
-static void gnome_db_login_class_init (GnomeDbLoginClass *klass);
-static void gnome_db_login_init       (GnomeDbLogin *login, GnomeDbLoginClass *klass);
-static void gnome_db_login_finalize   (GObject *object);
+static void gnome_db_login_class_init   (GnomeDbLoginClass *klass);
+static void gnome_db_login_init         (GnomeDbLogin *login, GnomeDbLoginClass *klass);
+static void gnome_db_login_set_property (GObject *object,
+					 guint paramid,
+					 const GValue *value,
+					 GParamSpec *pspec);
+static void gnome_db_login_get_property (GObject *object,
+					 guint param_id,
+					 GValue *value,
+					 GParamSpec *pspec);
+static void gnome_db_login_finalize     (GObject *object);
+
+enum {
+	PROP_0,
+	PROP_DSN,
+	PROP_USERNAME,
+	PROP_PASSWORD
+};
 
 static GObjectClass *parent_class = NULL;
 
@@ -82,7 +97,20 @@ gnome_db_login_class_init (GnomeDbLoginClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	object_class->set_property = gnome_db_login_set_property;
+	object_class->get_property = gnome_db_login_get_property;
 	object_class->finalize = gnome_db_login_finalize;
+
+	/* add class properties */
+	g_object_class_install_property (
+		object_class, PROP_DSN,
+		g_param_spec_string ("dsn", NULL, NULL, NULL, G_PARAM_READABLE));
+	g_object_class_install_property (
+		object_class, PROP_USERNAME,
+		g_param_spec_string ("username", NULL, NULL, NULL, G_PARAM_READABLE));
+	g_object_class_install_property (
+		object_class, PROP_PASSWORD,
+		g_param_spec_string ("password", NULL, NULL, NULL, G_PARAM_READABLE));
 }
 
 static void
@@ -93,6 +121,49 @@ gnome_db_login_init (GnomeDbLogin *login, GnomeDbLoginClass *klass)
 	login->priv->dsn_name = NULL;
 }
 
+static void
+gnome_db_login_set_property (GObject *object,
+			     guint param_id,
+			     const GValue *value,
+			     GParamSpec *pspec)
+{
+	GnomeDbLogin *login = (GnomeDbLogin *) object;
+
+	g_return_if_fail (GNOME_DB_IS_LOGIN (login));
+
+	switch (param_id) {
+	default :
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
+static void
+gnome_db_login_get_property (GObject *object,
+			       guint param_id,
+			       GValue *value,
+			       GParamSpec *pspec)
+{
+	GnomeDbLogin *login = (GnomeDbLogin *) object;
+
+	g_return_if_fail (GNOME_DB_IS_LOGIN (login));
+
+	switch (param_id) {
+	case PROP_DSN :
+		g_value_set_string (value, gnome_db_login_get_dsn (login));
+		break;
+	case PROP_USERNAME :
+		g_value_set_string (value, gnome_db_login_get_username (login));
+		break;
+	case PROP_PASSWORD :
+		g_value_set_string (value, gnome_db_login_get_password (login));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
 static void
 gnome_db_login_finalize (GObject *object)
 {
