@@ -32,14 +32,29 @@ struct _GnomeDbWindowPrivate {
 	GtkWidget *progress_bar;
 };
 
-static void gnome_db_window_class_init (GnomeDbWindowClass *klass);
-static void gnome_db_window_init       (GnomeDbWindow *window, GnomeDbWindowClass *klass);
-static void gnome_db_window_finalize   (GObject *object);
+static void gnome_db_window_class_init   (GnomeDbWindowClass *klass);
+static void gnome_db_window_init         (GnomeDbWindow *window, GnomeDbWindowClass *klass);
+static void gnome_db_window_set_property (GObject *object,
+					  guint paramid,
+					  const GValue *value,
+					  GParamSpec *pspec);
+static void gnome_db_window_get_property (GObject *object,
+					  guint param_id,
+					  GValue *value,
+					  GParamSpec *pspec);
+static void gnome_db_window_finalize     (GObject *object);
 
 enum {
 	CLOSE,
 	LAST_SIGNAL
 };
+
+enum {
+	PROP_0,
+	PROP_CONTENTS,
+	PROP_STATUS
+};
+
 static gint db_window_signals[LAST_SIGNAL];
 static GObjectClass *parent_class = NULL;
 
@@ -53,6 +68,22 @@ gnome_db_window_class_init (GnomeDbWindowClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	object_class->set_property = gnome_db_window_set_property;
+	object_class->get_property = gnome_db_window_get_property;
+	object_class->finalize = gnome_db_window_finalize;
+	klass->close = NULL; // FIXME: add default close handler
+
+	/* add class properties */
+	g_object_class_install_property (
+		object_class, PROP_CONTENTS,
+		g_param_spec_object ("contents", NULL, NULL,
+				     GTK_TYPE_WIDGET,
+				     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+	g_object_class_install_property (
+		object_class, PROP_STATUS,
+		g_param_spec_string ("status", NULL, NULL, NULL, G_PARAM_WRITABLE));
+
+	/* add class signals */
 	db_window_signals[CLOSE] =
 		g_signal_new ("close",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -61,9 +92,6 @@ gnome_db_window_class_init (GnomeDbWindowClass *klass)
 		              NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
-
-	object_class->finalize = gnome_db_window_finalize;
-	klass->close = NULL; // FIXME: add default close handler
 }
 
 static void
@@ -73,6 +101,67 @@ gnome_db_window_init (GnomeDbWindow *window, GnomeDbWindowClass *klass)
 	window->priv->progress_bar = NULL;
 }
 
+static void
+gnome_db_window_set_property (GObject *object,
+			      guint param_id,
+			      const GValue *value,
+			      GParamSpec *pspec)
+{
+	GnomeDbWindow *window = (GnomeDbWindow *) object;
+
+	g_return_if_fail (GNOME_DB_IS_WINDOW (window));
+
+	switch (param_id) {
+	case PROP_CONTENTS :
+		gnome_db_window_set_contents (
+			window,
+			GTK_WIDGET (g_value_get_object (value)));
+		break;
+	case PROP_STATUS :
+		gnome_db_window_set_status (window, g_value_get_string (value));
+		break;
+	default :
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
+static void
+gnome_db_window_get_property (GObject *object,
+			      guint param_id,
+			      GValue *value,
+			      GParamSpec *pspec)
+{
+	GnomeDbWindow *window = (GnomeDbWindow *) object;
+
+	g_return_if_fail (GNOME_DB_IS_WINDOW (window));
+
+	switch (param_id) {
+	case PROP_CONTENTS :
+		g_value_set_object (value,
+				    G_OBJECT (gnome_db_window_get_contents (window)));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
+static void
+gnome_db_window_finalize (GObject *object)
+{
+	GnomeDbWindow *window = (GnomeDbWindow *) object;
+
+	g_return_if_fail (GNOME_DB_IS_WINDOW (window));
+
+	/* free memory */
+	g_free ((gpointer) window->priv);
+	window->priv = NULL;
+
+	/* chain to parent handler */
+	parent_class->finalize (object);
+}
+
 GType
 gnome_db_window_get_type (void)
 {
@@ -95,21 +184,6 @@ gnome_db_window_get_type (void)
 	return type;
 }
 
-static void
-gnome_db_window_finalize (GObject *object)
-{
-	GnomeDbWindow *window = (GnomeDbWindow *) object;
-
-	g_return_if_fail (GNOME_DB_IS_WINDOW (window));
-
-	/* free memory */
-	g_free ((gpointer) window->priv);
-	window->priv = NULL;
-
-	/* chain to parent handler */
-	parent_class->finalize (object);
-}
-
 /**
  * gnome_db_window_new
  * @name: name of the window 
@@ -158,7 +232,7 @@ gnome_db_window_new (const gchar *name,
 		bonobo_ui_component_thaw (window->priv->ui_component, NULL);
 	}
 
-	return window;
+	return GTK_WIDGET (window);
 }
 
 /**
